@@ -35,7 +35,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (defpackage "SERVE-EVENT"
-  (:use "CL" "FFI" "UFFI")
+  (:use "CL" "FFI")
   (:export "WITH-FD-HANDLER" "ADD-FD-HANDLER" "REMOVE-FD-HANDLER"
            "SERVE-EVENT" "SERVE-ALL-EVENTS"))
 (in-package "SERVE-EVENT")
@@ -56,20 +56,11 @@
 (define-c-constants
     +eintr+ "EINTR")
 
-(defmethod ext::stream-fd ((stream t))
-  (etypecase stream
-    (fixnum stream)
-    (two-way-stream (ext::stream-fd (two-way-stream-input-stream stream)))
-    (file-stream (si:file-stream-fd stream))
-    (otherwise (error "In SERVE-EVENT, stream~%  ~A~%does not have an associated file descriptor" stream))))
-
 (defstruct (handler
-            (:constructor make-handler (direction stream-or-descriptor function
-                                        &aux (descriptor (ext::stream-fd stream-or-descriptor))))
+            (:constructor make-handler (descriptor direction function))
             (:copier nil))
   ;; Reading or writing...
   (direction nil :type (member :input :output))
-  (stream-or-descriptor nil)
   ;; File descriptor this handler is tied to.
   ;; FIXME: Should be based on FD_SETSIZE
   (descriptor 0)
@@ -81,16 +72,35 @@
   #!+sb-doc
   "List of all the currently active handlers for file descriptors")
 
+(defun coerce-to-descriptor (stream-or-fd direction)
+  (etypecase stream-or-fd
+    (fixnum stream-or-fd)
+    (file-stream (si:file-stream-fd stream-or-fd))
+    (two-way-stream
+     (coerce-to-descriptor
+      (case direction
+        (:input  (two-way-stream-input-stream  stream-or-fd))
+        (:output (two-way-stream-output-stream stream-or-fd)))
+      direction))
+    #+clos-streams
+    (stream (gray::stream-file-descriptor stream-or-fd direction))))
 
 ;;; Add a new handler to *descriptor-handlers*.
-(defun add-fd-handler (fd direction function)
-  "Arrange to call FUNCTION whenever FD is usable. DIRECTION should be
-  either :INPUT or :OUTPUT. The value returned should be passed to
-  SYSTEM:REMOVE-FD-HANDLER when it is no longer needed."
+(defun add-fd-handler (stream-or-fd direction function)
+  "Arrange to call FUNCTION whenever the fd designated by STREAM-OR-FD
+  is usable. DIRECTION should be either :INPUT or :OUTPUT. The value
+  returned should be passed to SYSTEM:REMOVE-FD-HANDLER when it is no
+  longer needed."
   (unless (member direction '(:input :output))
-    ;; FIXME: should be TYPE-ERROR?
-    (error "Invalid direction ~S, must be either :INPUT or :OUTPUT" direction))
-  (let ((handler (make-handler direction fd function)))
+    (error 'simple-type-error
+           :format-control "Invalid direction ~S, must be either ~
+                            :INPUT or :OUTPUT."
+           :format-arguments (list direction)
+           :datum direction
+           :expected-type '(member :input :output)))
+  (let ((handler (make-handler (coerce-to-descriptor stream-or-fd direction)
+                               direction
+                               function)))
     (push handler *descriptor-handlers*)
     handler))
 
@@ -165,19 +175,19 @@
           (setf maxfd fd))))
 
         (multiple-value-bind (retval errno)
-	    (if (null seconds)
-		;; No timeout
-		(c-inline (rfd      wfd    (1+ maxfd))
-			  (:object :object :int) (values :int :int)
-			  "{ @(return 0) = select(#2, (fd_set*)#0->foreign.data,
+            (if (null seconds)
+                ;; No timeout
+                (c-inline (rfd      wfd    (1+ maxfd))
+                          (:object :object :int) (values :int :int)
+                          "{ @(return 0) = select(#2, (fd_set*)#0->foreign.data,
                                                       (fd_set*)#1->foreign.data,
                                                       NULL, NULL);
                              @(return 1) = errno; }"
-			  :one-liner nil
-			  :side-effects t)
-		(c-inline (rfd      wfd    (1+ maxfd) seconds) 
-			  (:object :object :int       :double) (values :int :int)
-			  "{ struct timeval tv;
+                          :one-liner nil
+                          :side-effects t)
+                (c-inline (rfd      wfd    (1+ maxfd) seconds) 
+                          (:object :object :int       :double) (values :int :int)
+                          "{ struct timeval tv;
                              double seconds = #3;
                                 tv.tv_sec = seconds;
                                 tv.tv_usec = (seconds * 1e6);
@@ -185,26 +195,26 @@
                                                          (fd_set*)#1->foreign.data,
                                                          NULL, &tv);
                                 @(return 1) = errno; }"
-			  :one-liner nil
-			  :side-effects t))
+                          :one-liner nil
+                          :side-effects t))
 
-	  (cond ((zerop retval) 
-		 nil)
-		((minusp retval)
-		 (if (= errno +eintr+)
-		     ;; suppress EINTR
-		     nil
-		     ;; otherwise error
-		     (error "Error during select")))
-		((plusp retval)  
-		 (dolist (handler *descriptor-handlers*)
-		   (let ((fd (handler-descriptor handler)))
-		     (if (plusp (ecase (handler-direction handler)
-				  (:input (fd-isset fd rfd))
-				  (:output (fd-isset fd wfd))))
-			 (funcall (handler-function handler) 
-				  (handler-descriptor handler)))))
-		 t)))))))
+          (cond ((zerop retval) 
+                 nil)
+                ((minusp retval)
+                 (if (= errno +eintr+)
+                     ;; suppress EINTR
+                     nil
+                     ;; otherwise error
+                     (error "Error during select")))
+                ((plusp retval)  
+                 (dolist (handler *descriptor-handlers*)
+                   (let ((fd (handler-descriptor handler)))
+                     (if (plusp (ecase (handler-direction handler)
+                                  (:input (fd-isset fd rfd))
+                                  (:output (fd-isset fd wfd))))
+                         (funcall (handler-function handler) 
+                                  (handler-descriptor handler)))))
+                 t)))))))
 
 
 ;;; Wait for up to timeout seconds for an event to happen. Make sure all
@@ -219,4 +229,4 @@ T if SERVE-EVENT did something and NIL if not."
       ((null sval) res)
     (setq res t)))
 
-(provide 'serve-event)
+(provide '#:serve-event)
